@@ -181,7 +181,7 @@ QWidget* MainWindow::createConfirmWidget()
 
     QProgressBar *downloadProgressBar = new QProgressBar();
     downloadProgressBar->setVisible(false);
-    downloadProgressBar->setFormat(i18nc("Progress percent value", "%1%"));
+    downloadProgressBar->setFormat(i18nc("Progress percent value", "%p%"));
     downloadProgressBar->setMinimum(0);
     downloadProgressBar->setMaximum(100);
     connect(this, &MainWindow::downloadProgressChanged, downloadProgressBar, &QProgressBar::show);
@@ -219,7 +219,7 @@ QWidget* MainWindow::createProgressWidget()
     messageLabel->setWordWrap(true);
 
     m_progressBar = new QProgressBar;
-    m_progressBar->setFormat(i18nc("Progress percent value", "%1%"));
+    m_progressBar->setFormat(i18nc("Progress percent value", "%p%"));
     m_cancelButton = new QPushButton(i18n("Cancel"));
 
     QVBoxLayout *mainVBoxLayout = new QVBoxLayout;
