@@ -18,7 +18,7 @@
 #include <io.h>
 #endif
 
-#if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
 #include <unistd.h>
 #endif
 
